# Oracle EBS Connector Demo - Party Site CRUD

## Introduction
The present demo enables the user to create, read and update objects via the Party Site Business Object Services.

## Prerequisites
In order to run this demo project you will need:

* Anypoint Studio 5.4.x or higher.
* Mule Runtime 3.7.x EE or higher.
* DataWeave.
* Oracle EBS Connector v4.0.0.
* Oracle E-Business Suite instance v12.1.x.
* Web services credentials for the instance.

## Import the project

* Go to **File > Import**
* Select **Anypoint Studio Project from External Location** (under the parent folder "Anypoint Studio")

![Menu](images/import_menu.png)

* Provide the root path to the demo project folder.
* Select Mule Runtime (3.7.x EE).

![File Selection](images/import_file.png)

* Click **Finish**.  
* Set your EBS credentials inside the file `src/main/app/mule-app.properties`, alongside some other required values.

```
username=<username for web services>
password=<password>
host=<EBS instance host>
port=<EBS instance port for web services>
responsibilityName=<responsibility name>
responsibilityApplName=<responsibility application name>

createdByModule=
validateObjFlag=
parentId=
parentObjType=
```
* Inside the Global Elements view, double-click the _OracleEBS: Configuration_ component and click on "Test Connection".

![Test Connection](images/config_connection.png)

 * A successful message should pop-up.

![Test Connection](images/config_connection_success.png)

* If you see an error message, check if the following can resolve your problem:

    1. **`Unsupported major/minor version 51.0`**: it indicates that you are running with a 1.6 JRE. Ensure that you are running with Java 1.7 and restart Studio.

> For further information, refer to the [Oracle EBS Connector Documentation Guide](https://docs.mulesoft.com/mule-user-guide/v/3.8/oracle-ebs-connector-user-guide).

* Select **Run as Mule Application**. You should see the demo application deployed.

* Open a browser and access the URL `http://localhost:8081`. You should see the demo application deployed:

![Workflow Demo](images/import_demo.png)

## About the flows

**html-form-flow :** This flow represents the user's entry point. Its purpose is serving the form.html file.

![Flow html-form-flow](images/flow_html-form-flow.png)

**createPartySite :** This flow lets you create a Party Site object into your EBS instance.

![Flow createPartySite](images/flow_createPartySite.png)

**getPartySite :** This flow will retrieve a Party Site object, given a ```partySiteId```.

![Flow getPartySite](images/flow_getPartySite.png)

**updatePartySite :** This flow will update an existing Party Site record.

![Flow updatePartySite](images/flow_updatePartySite.png)

## Run the demo

### Creating a Party Site

* Make sure that the **Create** panel is open.

![Create Form](images/create_form.png)

* Fill in the fields to create a Party Site, or use the default values.
* Click on **Create**.
* You will see the response from the Mule app in the **Response** section.

![Create Response](images/create_response.png)

### Getting a Party Site
* Make sure that the **Get** panel is open.

![Get Form](images/get_form.png)

* Fill in the ID for the Party Site you want to fetch. If you have just created one using the demo, this field will be automatically populated with the ID of the newly created one.
* Click on **Get**.
* You will see the response from the Mule app in the **Response** section.

![Get Response](images/get_response.png)

### Updating an existing Party Site

* Make sure that the **Update** panel is open.

![Update Form](images/update_form.png)

* Fill in the ID for the Party Site you want to update, and the fields to update. If you have just created one using the demo, these fields will be automatically populated.
* Click on **Update**.
* You will see the response from the Mule app in the **Response** section.

![Update Response](images/update_response.png)
